==> pcl_1.10.0+dfsg.orig.tar.xz: pcl-pcl-1.10.0/io/src/depth_sense_grabber.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2014-, Open Perception, Inc.
 *
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the copyright holder(s) nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <pcl/io/depth_sense_grabber.h>
#include <pcl/io/depth_sense/depth_sense_grabber_impl.h>

pcl::DepthSenseGrabber::DepthSenseGrabber (const std::string& device_id)
: Grabber ()
, p_ (new pcl::io::depth_sense::DepthSenseGrabberImpl (this, device_id))
{
}

pcl::DepthSenseGrabber::~DepthSenseGrabber () throw ()
{
  delete p_;
}

void
pcl::DepthSenseGrabber::start ()
{
  p_->start();
}

void
pcl::DepthSenseGrabber::stop ()
{
  p_->stop();
}

bool
pcl::DepthSenseGrabber::isRunning () const
{
  return (p_->is_running_);
}

float
pcl::DepthSenseGrabber::getFramesPerSecond () const
{
  return (p_->getFramesPerSecond());
}

void
pcl::DepthSenseGrabber::setConfidenceThreshold (int threshold)
{
  p_->setConfidenceThreshold (threshold);
}

void
pcl::DepthSenseGrabber::enableTemporalFiltering (TemporalFilteringType type, std::size_t window_size)
{
  p_->enableTemporalFiltering (type, window_size);
}

void
pcl::DepthSenseGrabber::disableTemporalFiltering ()
{
  p_->enableTemporalFiltering (DepthSense_None, 1);
}

std::string
pcl::DepthSenseGrabber::getDeviceSerialNumber () const
{
  return (p_->device_id_);
}

==> pcl_1.11.1+dfsg.orig.tar.xz: pcl-pcl-1.11.1/io/src/depth_sense_grabber.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2014-, Open Perception, Inc.
 *
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the copyright holder(s) nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <pcl/io/depth_sense_grabber.h>
#include <pcl/io/depth_sense/depth_sense_grabber_impl.h>

pcl::DepthSenseGrabber::DepthSenseGrabber (const std::string& device_id)
: Grabber ()
, p_ (new pcl::io::depth_sense::DepthSenseGrabberImpl (this, device_id))
{
}

pcl::DepthSenseGrabber::~DepthSenseGrabber () noexcept
{
  delete p_;
}

void
pcl::DepthSenseGrabber::start ()
{
  p_->start();
}

void
pcl::DepthSenseGrabber::stop ()
{
  p_->stop();
}

bool
pcl::DepthSenseGrabber::isRunning () const
{
  return (p_->is_running_);
}

float
pcl::DepthSenseGrabber::getFramesPerSecond () const
{
  return (p_->getFramesPerSecond());
}

void
pcl::DepthSenseGrabber::setConfidenceThreshold (int threshold)
{
  p_->setConfidenceThreshold (threshold);
}

void
pcl::DepthSenseGrabber::enableTemporalFiltering (TemporalFilteringType type, std::size_t window_size)
{
  p_->enableTemporalFiltering (type, window_size);
}

void
pcl::DepthSenseGrabber::disableTemporalFiltering ()
{
  p_->enableTemporalFiltering (DepthSense_None, 1);
}

std::string
pcl::DepthSenseGrabber::getDeviceSerialNumber () const
{
  return (p_->device_id_);
}
